;; Generated package description from vc-jj.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "vc-jj" "0.5.0.20260324.165127" "VC backend for the Jujutsu version control system" '((emacs "28.1") (compat "29.4")) :commit "c8df3b6092292c760522851e8a89f4525eb70cf1" :authors '(("Rudolf Schlatte" . "rudi@constantly.at") ("Kristoffer Balintona" . "krisbalintona@gmail.com")) :maintainer '(("Rudolf Schlatte" . "rudi@constantly.at") ("Kristoffer Balintona" . "krisbalintona@gmail.com")) :keywords '("vc" "tools") :url "https://codeberg.org/emacs-jj-vc/vc-jj.el")
